@@ -3,8 +3,6 @@
 #include <R.h>
 #include <Rinternals.h>
 
-#ifdef USE_PROJ6_API
-
 #include <proj.h>
 
 SEXP C_proj_crs_text(SEXP crs_, SEXP format)
@@ -67,16 +65,3 @@ SEXP C_proj_crs_text(SEXP crs_, SEXP format)
 
   return(out);
 }
-
-
-#else
-
-SEXP C_proj_crs_text(SEXP crs_, SEXP format)
-{
- SEXP out = PROTECT(allocVector(STRSXP, 1));
- SET_STRING_ELT(out, 0, NA_STRING);
- UNPROTECT(1);
- return out;
-}
-
-#endif
